@@ -94,7 +94,8 @@ my $configure_wordpress=sub {
       $ip=~s/^.*?(\d+.\d+.\d+.\d+).*$/$1/s;
    }
    my $userhome=$handle->cmd('pwd');
-   ($stdout,$stderr)=$handle->cmd("${sudo}perl -e \'use CPAN;".
+   ($stdout,$stderr)=$handle->cmd(
+      "perl -e \'use CPAN;".
       "CPAN::HandleConfig-\>load;print \$CPAN::Config-\>{build_dir}\'");
    $builddir=$stdout;
    my $fa_ver=$Net::FullAuto::VERSION;
@@ -104,7 +105,6 @@ my $configure_wordpress=sub {
    foreach my $line (@lstmp) {
       unshift @ls_tmp, $line if $line!~/\.yml$/;
    }
-
 $do=1;
 if ($do==1) {
    unless ($^O eq 'cygwin') {
@@ -977,7 +977,7 @@ END
             '__display__');
          ($stdout,$stderr)=$handle->cwd("/etc/nginx");
          sleep 3;
-         &Net::FullAuto::FA_Core::clean_filehandle($handle);
+         ($stdout,$stderr)=&Net::FullAuto::FA_Core::clean_filehandle($handle);
          $handle->{_cmd_handle}->print($sudo.
             'certbot --nginx -d get-wisdom.com '.
             '-d www.get-wisdom.com');
@@ -1541,7 +1541,7 @@ END
 }
 
 .site-branding .site-description {
-   color: orangered;
+   color: orange;
 }
 END
    ($stdout,$stderr)=$handle->cmd("echo -e \"$oc_style\" > ".
@@ -1726,10 +1726,6 @@ if ($do==1) {
          simple-trackback-validation-with-topsy-blocker
          text-hover
          theme-my-login
-         woocommerce
-         woocommerce-gateway-paypal-powered-by-braintree
-         woocommerce-services
-         woocommerce-gateway-stripe
          wpfront-notification-bar
          wp-to-twitter
          wordpress-seo
@@ -1774,15 +1770,13 @@ my $curyear=$thisyear + 1900;
    "mkdir -vp /var/www/html/wordpress/wp-content/uploads/$curyear/$mo_",
    '__display__');
 ($stdout,$stderr)=$handle->cmd($sudo.
-   "cp -v $builddir/$ls_tmp[0]/dependencies/gw/angelwing75.png ".
-   "/var/www/html/wordpress/wp-content/uploads/$curyear/$mo_",'__display__');
-($stdout,$stderr)=$handle->cmd($sudo.
-   "cp -v $builddir/$ls_tmp[0]/dependencies/gw/angelwing75-80x75.png ".
-   "/var/www/html/wordpress/wp-content/uploads/$curyear/$mo_",'__display__');
-($stdout,$stderr)=$handle->cmd($sudo.
-   "cp -v $builddir/$ls_tmp[0]/dependencies/gw/gw_background.png ".
-   "/var/www/html/wordpress/wp-content/uploads/$curyear/$mo_",'__display__');
-
+   "/usr/local/bin/wp media import $builddir/$ls_tmp[0]/dependencies/gw/* ".
+   "--path=/var/www/html/wordpress --allow-root",'__display__');
+($stdout,$stderr)=$handle->cmd($sudo."/usr/local/bin/".
+   "wp db query \"select post_id from wp_postmeta where meta_value like ".
+   "'%angelwing75%'\" --path=/var/www/html/wordpress --allow-root");
+$stdout=~s/^.*(\d+)$/$1/s;
+my $post_id=$stdout;
 $handle->{_cmd_handle}->print('mysql -u root --password='.$service_and_cert_password);
 $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
 $cmd_sent=0;
@@ -1801,13 +1795,7 @@ while (1) {
       next;
    } elsif ($cmd_sent>=1 && $output=~/mysql>\s*$/) {
       print "quit\n";
-      my $cmd='UPDATE wordpress.wp_postmeta SET meta_value =\'a:5:{s:5:"width";i:100;s:6:"height";i:75;s:4:"file";s:23:"'.$curyear.'/'.$mo_.'/angelwing75.png";s:5:"sizes";a:1:{s:4:"mini";a:4:{s:4:"file";s:21:"angelwing75-80x75.png";s:5:"width";i:80;s:6:"height";i:75;s:9:"mime-type";s:9:"image/png";}}s:10:"image_meta";a:12:{s:8:"aperture";s:1:"0";s:6:"credit";s:0:"";s:6:"camera";s:0:"";s:7:"caption";s:0:"";s:17:"created_timestamp";s:1:"0";s:9:"copyright";s:0:"";s:12:"focal_length";s:1:"0";s:3:"iso";s:1:"0";s:13:"shutter_speed";s:1:"0";s:5:"title";s:0:"";s:11:"orientation";s:1:"0";s:8:"keywords";a:0:{}}}\' WHERE meta_key = \'_wp_attachment_metadata\';';
-      $handle->{_cmd_handle}->print($cmd);
-      sleep 1;
-      next;
-   } elsif ($cmd_sent>=2 && $output=~/mysql>\s*$/) {
-      print "quit\n";
-      $handle->{_cmd_handle}->print('quit');
+      $handle->{_cmd_handle}->print('quit;');
       sleep 1;
       next;
    } sleep 1;
@@ -1831,36 +1819,45 @@ if ($do==1) {
       '&wp-submit=Log+In&redirect_to='.$url.
       '%2Fwp-admin%2F&testcookie=1" https://'.$urll.
       '/wp-login.php');
-   ($stdout,$stderr)=$handle->cmd(
-      "curl -k -L -b ~/cookies.txt 'https://".$urll.'/wp-admin/'.
-      "customize.php?url=".$url."%2F' ".
-      "-H 'Accept: text/html,".
-      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
-      "-H 'Accept-Encoding: gzip, deflate, br' ".
-      "-H 'Accept-Language: en-US,en;q=0.5' ".
-      "-H 'Connection: keep-alive' ".
-      "-H 'Host: ".$urll."' ".
-      "-H 'Referer: https://".$urll."/' ".
-      "-H 'Upgrade-Insecure-Requests: 1' ".
-      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
-      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
-   ($stdout,$stderr)=$handle->cmd(
-      "curl -k -L -b ~/cookies.txt 'https://".$urll.'/wp-admin/'.
-      "customize.php?url=".$url."%2F' ".
-      "-H 'Accept: text/html,".
-      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
-      "-H 'Accept-Encoding: gzip, deflate, br' ".
-      "-H 'Accept-Language: en-US,en;q=0.5' ".
-      "-H 'Connection: keep-alive' ".
-      "-H 'Host: ".$urll."' ".
-      "-H 'Referer: https://".$urll."/' ".
-      "-H 'Upgrade-Insecure-Requests: 1' ".
-      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
-      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
-   $stdout=~s/^.*_wpCustomizeSettings = (.*?)[}][}][}].*$/$1/s;
+   sleep 5;
+   my $nonce_cmd="curl -k -L -b ~/cookies.txt 'https://".$urll.'/wp-admin/'.
+         "customize.php?url=".$url."%2F' ".
+         "-H 'Accept: text/html,".
+         "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
+         "-H 'Accept-Encoding: gzip, deflate, br' ".
+         "-H 'Accept-Language: en-US,en;q=0.5' ".
+         "-H 'Connection: keep-alive' ".
+         "-H 'Host: ".$urll."' ".
+         "-H 'Referer: https://".$urll."/' ".
+         "-H 'Upgrade-Insecure-Requests: 1' ".
+         "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
+         "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'";
+   my $one=1;
+   $handle->{_cmd_handle}->print($nonce_cmd);
+   while ($one==1) {
+      my $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
+      $handle->{_cmd_handle}->print($nonce_cmd);
+      while (1) {
+         my $output.=Net::FullAuto::FA_Core::fetch($handle);
+         $stdout.=$output;
+         last if $output=~/$prompt/;
+         print $output;
+      }
+      $stdout=~s/^.*_wpCustomizeSettings = (.*?)[}][}][}].*$/$1/s;
+      last if -1<index $stdout,'"nonce":{';
+      ($stdout,$stderr)=&Net::FullAuto::FA_Core::clean_filehandle($handle);
+      ($stdout,$stderr)=$handle->cmd(
+         'curl -v -k --cookie-jar ~/cookies.txt --max-redirs 0 '.
+         '--data "log='.$adu.'&pwd='.$service_and_cert_password.
+         '&wp-submit=Log+In&redirect_to='.$url.
+         '%2Fwp-admin%2F&testcookie=1" https://'.$urll.
+         '/wp-login.php');
+      sleep 4;
+   }
    my $nonce=$stdout;
    my $uuid=$stdout;
    $nonce=~s/^.*nonce["]:([{].*?[}]),.*$/$1/s;
+print "NONCE=$nonce\n";sleep 5;
    my $nonce_hash=decode_json($nonce);
 #print "NONCE=$nonce<==NONCE and SAVE=$nonce_hash->{save} and PREVIEW=$nonce_hash->{preview}\n";<STDIN>;
    $uuid=~s/^.*uuid["]:["](.*?)["],.*$/$1/s;
@@ -1916,9 +1913,94 @@ print "CUSTOMIZE_SAVE STDOUT=$stdout<== and STDERR=$stderr<==\n";
       "-H 'Referer: https://".$urll."/wp-admin/customize.php?url=https%3A%2F%2F$urll%2F&changeset_uuid=$uuid' ".
       "-H 'Connection: keep-alive' ".
       "--data 'wp_customize=on&customize_theme=memberlite-child&nonce=".$nonce_hash->{save}."&customize_changeset_uuid=$uuid&customized=%7B%22blogdescription%22%3A%22Revealing+and+Healing+the+Number+One+Cause+of+Human+Difficulty%22%7D&customize_changeset_status=publish&action=customize_save&customize_preview_nonce=".$nonce_hash->{preview}."'");
+print "WHAT IS HEALING STDOUT=$stdout\n";
+
+##############################################################
+
+   ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b ~/cookies.txt 'https://".$urll.'/wp-admin/'.
+      "customize.php?url=".$url."%2F' ".
+      "-H 'Accept: text/html,".
+      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Host: ".$urll."' ".
+      "-H 'Referer: https://".$urll."/' ".
+      "-H 'Upgrade-Insecure-Requests: 1' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
+      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
+    $stdout=~s/^.*_wpCustomizeSettings = (.*?)[}][}][}].*$/$1/s;
+    $nonce=$stdout;
+    $uuid=$stdout;
+    $nonce=~s/^.*nonce["]:([{].*?[}]),.*$/$1/s;
+    $nonce_hash=decode_json($nonce);
+    $uuid=~s/^.*uuid["]:["](.*?)["],.*$/$1/s;
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b ~/cookies.txt 'https://".$urll.'/wp-admin/'.
+      "customize.php?url=".$url."%2F&changeset_uuid=$uuid".
+      "&customize_theme=memberlite-child&customize_messenger_channel=preview-0' ".
+      "-H 'Accept: text/html,".
+      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Host: ".$urll."' ".
+      "-H 'Referer: https://".$urll."/' ".
+      "-H 'Upgrade-Insecure-Requests: 1' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
+      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
+    $stdout=~s/^.*_wpCustomizeSettings = (.*?)[}][}][}].*$/$1/s;
+    $nonce=$stdout;
+    $uuid=$stdout;
+    $nonce=~s/^.*nonce["]:([{].*?[}]),.*$/$1/s;
+    $nonce_hash=decode_json($nonce);
+    $uuid=~s/^.*uuid["]:["](.*?)["],.*$/$1/s;
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b ~/cookies.txt 'https://".$urll."/?customize_changeset_uuid=".$uuid."&customize_autosaved=on&customize_preview_nonce=".$nonce_hash->{preview}."' ".
+      "-H 'Host: ".$urll."' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0' ".
+      "-H 'Accept: */*' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Content-Type: application/x-www-form-urlencoded; charset=UTF-8' ".
+      "-H 'Referer: https://".$urll."/' ".
+      "-H 'Upgrade-Insecure-Requests: 1' ".
+      "--data 'wp_customize=on&nonce=".$nonce_hash->{preview}."&customize_theme=memberlite-child&customized=%7B%22custom_logo%22%3A".$post_id."%7D&customize_changeset_uuid=".$uuid."&partials=%7B%22custom_logo%22%3A%5B%7B%7D%5D%7D&wp_customize_render_partials=1&action=&customized=%7B%22custom_logo%22%3A".$post_id."%7D'");
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b ~/cookies.txt 'https://".$urll."/wp-admin/admin-ajax.php' ".
+      "-H 'Accept: */*' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Content-Type: application/x-www-form-urlencoded; charset=UTF-8' ".
+      "-H 'Host: ".$urll."' ".
+      "-H 'Referer: https://".$urll."/wp-admin/customize.php?url=https%3A%2F%2F".$urll."%2Fchangeset_uuid=".$uuid."' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0' ".
+      "-H 'X-Requested-With: XMLHttpRequest' ".
+      "--data 'wp_customize=on&customize_theme=memberlite-child&nonce=".$nonce_hash->{save}."&customize_changeset_uuid=".$uuid."&customize_autosaved=on&customized=%7B%22custom_logo%22%3A".$post_id."%7D&customize_changeset_status=publish&action=customize_save&customize_preview_nonce=".$nonce_hash->{preview}."'");
+
+print "WHAT IS LOGO STDOUT=$stdout\n";
 
 }
 
+   my @wp_plugins=qw(
+
+         woocommerce
+         woocommerce-gateway-paypal-powered-by-braintree
+         woocommerce-services
+         woocommerce-gateway-stripe
+
+   );
+
+   foreach my $plugin (@wp_plugins) {
+      last if $plugin=~/^#/;
+      ($stdout,$stderr)=$handle->cmd(
+         "/usr/local/bin/wp plugin install $plugin --allow-root ".
+         "--activate --path=/var/www/html/wordpress",
+         '__display__');
+   }
+
    my $thanks=<<'END';
 
      ______                  _    ,
